# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['knock_knock', 'knock_knock.test']

package_data = \
{'': ['*'],
 'knock_knock': ['example_data/*',
                 'example_data/data/illumina/*',
                 'example_data/data/pacbio/*',
                 'example_data/targets/*',
                 'table_template/*'],
 'knock_knock.test': ['indices/bosTau7/STAR/*',
                      'indices/e_coli/STAR/*',
                      'indices/hg19/STAR/*',
                      'indices/hg38/STAR/*',
                      'read_sets/PE2_screen/*',
                      'read_sets/PE3+50_screen/*',
                      'read_sets/PE3-50_screen/*',
                      'read_sets/PE3_insertion_screen/*',
                      'read_sets/PMID31634902_Fig3B_HEK3_+026_1/*',
                      'read_sets/PMID31634902_fig_4G_HEK3_del1-5/*',
                      'read_sets/PMID31634902_fig_4G_HEK3_del1-80/*',
                      'read_sets/PMID31634902_fig_4H_FANCF_1AC_6GT/*',
                      'read_sets/PMID31634902_fig_4H_FANCF_1Tins_6GA/*',
                      'read_sets/PMID31634902_fig_4H_HEK3_1CTTins_5Gdel/*',
                      'read_sets/PMID31634902_fig_4H_RNF2_1CA_5GT/*',
                      'read_sets/PMID34887556_Fig1C_attB_A30_B30_1/*',
                      'read_sets/PMID34887556_Fig2C_PAH_E4_24bp_overlap_epegRNA_1/*',
                      'read_sets/PMID34887556_Fig2C_PAH_E7a_22bp_overlap_epegRNA_1/*',
                      'read_sets/PMID34887556_Fig2E_HEK3_PD_90_standard_1/*',
                      'read_sets/PMID34887556_Fig3C_AAVS1-1651+1652_A1246c_B1376a/*',
                      'read_sets/PMID34887556_Fig3C_AAVS1-1653+1715_A1615a_B1676a/*',
                      'read_sets/twin_prime_hybrid_anchor_34bp_del/*',
                      'read_sets/twin_prime_left_anchor_30bp_del/*',
                      'read_sets/twin_prime_single_base_conversion/*',
                      'targets/EMX1/*',
                      'targets/HEK3_attB_A30_B30/*',
                      'targets/PAH_E4-2_45_EvoPreQ1-4_43_EvoPreQ1/*',
                      'targets/PAH_E7-2_34_EvoPreQ1-5_34_EvoPreQ1/*',
                      'targets/PMID31634902_FANCF/*',
                      'targets/PMID31634902_HEK3/*',
                      'targets/PMID31634902_RNF2/*',
                      'targets/PMID34887556_AAVS1-1651+1652/*',
                      'targets/PMID34887556_AAVS1-1653+1715/*',
                      'targets/PMID34887556_HEK3/*',
                      'targets/PMID34887556_PAH-1696+1697/*',
                      'targets/PMID34887556_PAH-E4fe+1687/*',
                      'targets/pPC1000/*',
                      'targets/pPC1655/*']}

install_requires = \
['Pillow>=9.4.0,<10.0.0',
 'PyYAML>=6.0,<7.0',
 'biopython>=1.81,<2.0',
 'bokeh>=3.0.3,<4.0.0',
 'h5py>=3.8.0,<4.0.0',
 'hits>=0.3.3,<0.4.0',
 'ipywidgets>=8.0.4,<9.0.0',
 'matplotlib>=3.7.0,<4.0.0',
 'nbconvert>=7.2.9,<8.0.0',
 'nbformat>=5.7.3,<6.0.0',
 'numpy>=1.24.2,<2.0.0',
 'pandas>=1.5.3,<2.0.0',
 'pysam>=0.20.0,<0.21.0',
 'tqdm>=4.64.1,<5.0.0']

entry_points = \
{'console_scripts': ['knock-knock = knock_knock.knock:main']}

setup_kwargs = {
    'name': 'knock-knock-x',
    'version': '0.1.0',
    'description': "A modified version of Jeff's knock-knock.",
    'long_description': '# knock-knock \n\n`knock-knock` is a tool for exploring, categorizing, and quantifying the sequence outcomes produced by genome editing experiments.\n![](docs/example.png)\n\n## Installation ![](https://img.shields.io/pypi/pyversions/knock-knock.svg) [![](https://badge.fury.io/py/knock-knock.svg)](https://badge.fury.io/py/knock-knock) [![install with bioconda](https://img.shields.io/conda/vn/bioconda/knock-knock)](http://bioconda.github.io/recipes/knock-knock/README.html)\n\n### conda\n```\nconda config --add channels bioconda\nconda config --add channels conda-forge\nconda install knock-knock\n```\n### pip\n```\npip install knock-knock\n```\n\nIf installing with `pip`, non-Python dependencies need to be installed separately:\n- `blastn` (2.7.1)\n- `minimap2` (2.16)\n- `samtools` (1.9)\n- `STAR` (2.7.1)\n- `GNU parallel` (20190522)\n\n\n## About\n\n`knock-knock` tries to identify the different ways that genome editing experiments can produce unintended shufflings and rearrangments of the intended editing outcome.\nIn order to do this, the strategy used to align sequencing reads makes as few assumptions as possible about how the reads should look.\nInstead, it takes each amplicon sequencing read and attempts to produce a comprehensive set of local alignments between portions of the read and all relevant sequences present in the edited cell.\nEach read is then categorized by identifying a parsimonious subset of local alignments that cover the whole read and analyzing the architecture of this set of covering alignments. \n\n`knock-knock` supports Pacbio CCS data for longer (\\~thousands of nts) amplicons and paired-end Illumina data for shorter (\\~hundreds of nts) amplicons.\n\n## Visualization\n`knock-knock` provides a few ways to interactively explore the different types of alignment architectures produced by each experiment. Click [here](docs/visualization.md) for a guided tour, or [here](https://jeffhussmann.github.io/knock-knock_demo/) for a small live demo.\n\n### Summary table\n![](docs/table_demo.gif)\n\n### Outcome-stratified amplicon length distributions\n![](docs/lengths_demo.gif)\n\n## Getting started\n\nThis tutorial will walk you through the process of using knock-knock to analyze amplicon sequencing data of an editing experiment, broken down into six steps:\n1. [Setting up a project directory](#Setting-up-a-project-directory)\n1. [Obtain reference genomes and build alignment indices from them](#Obtaining-reference-sequences-and-building-indices)\n1. [Provide information about the genomic locii targeted for editing and HDR donor sequences](#Specifying-targets)\n1. [Fill out sample sheets associating each sample with sequencing data files and an editing strategy](#Sample-sheets)\n1. [Process data to generate alignments and classify outcomes](#Processing-samples)\n1. [Generate summary tables and visualizations](#Generating-tables)\n\n### Setting up a project directory\n\nThe first step in using knock-knock is to create a project directory that will hold all input data, references sequences, and analysis output for a given project.\n\nEvery time knock-knock is run, this directory is given as a command line argument to tell knock-knock which project to analyze.\n\nThroughout this documentation, `PROJECT_DIR` will be used as a stand-in for the path to an actual project directory.\n\nknock-knock is packaged with some small example data sets for testing purposes. To install this example data to a user-specified project directory, run \n\n```\nknock-knock install_example_data PROJECT_DIR\n```\n\nAfter running this command, PROJECT_DIR will contain \n\n```\nPROJECT_DIR\n├── data\n│\xa0\xa0 ├── illumina\n│\xa0\xa0 │\xa0\xa0 ├── BCAP31_ultramer_R1.fastq.gz\n│\xa0\xa0 │\xa0\xa0 ├── BCAP31_ultramer_R2.fastq.gz\n│\xa0\xa0 │\xa0\xa0 ├── CLTA_PCR_R1.fastq.gz\n│\xa0\xa0 │\xa0\xa0 ├── CLTA_PCR_R2.fastq.gz\n│\xa0\xa0 │\xa0\xa0 └── sample_sheet.csv\n│\xa0\xa0 └── pacbio\n│\xa0\xa0     ├── RAB11A_PCR.fastq.gz\n│\xa0\xa0     ├── RAB11A_plasmid.fastq.gz\n│\xa0\xa0     └── sample_sheet.csv\n└── targets\n    ├── amplicon_primers.csv\n    ├── donors.csv\n    ├── sgRNAs.csv\n    └── targets.csv\n```\n\n### Obtaining reference sequences and building indices\n\nOnce you have created a project directory, `knock-knock` needs to be provided with the reference genome of a targeted organism in fasta format in order to build indices from this reference.\nThese files are stored in directory called `indices` inside a project directory.\n\nknock-knock provides a built-in way to download references and build indices for human (hg38), mouse (mm10), or e. coli genomes. To do this, run\n\n```knock-knock build-indices PROJECT_DIR ORGANISM [--num-threads NUM_THREADS]```\n\nwhere ORGANISM is one of hg38, mm10, or e_coli, and NUM_THREADS is an optional argument that can be provided to use multiple threads for index building.\n(This can take up to several hours for mammalian-scale genomes.)\n\nRunning this command for hg38 will populate `PROJECT_DIR/indices/hg38` with the following files: \n\n```\nPROJECT_DIR/indices/hg38/\n├── STAR\n│\xa0\xa0 ├── Genome\n│\xa0\xa0 ├── SA\n│\xa0\xa0 ├── SAindex\n│\xa0\xa0 ├── chrLength.txt\n│\xa0\xa0 ├── chrName.txt\n│\xa0\xa0 ├── chrNameLength.txt\n│\xa0\xa0 ├── chrStart.txt\n│\xa0\xa0 └── genomeParameters.txt\n├── fasta\n│\xa0\xa0 ├── hg38.fa\n│\xa0\xa0 └── hg38.fa.fai\n└── minimap2\n    └── hg38.mmi\n```\n\nAlternatively, if reference genomes and indices already exist (e.g. in another project\'s directory), a YAML file `PROJECT_DIR/index_locations.yaml` that lists paths can be provided. \n\n### Specifying targets\n\nThe next step is to provide information about which genomic location was targeted for editing and the sequence of the donor that was provided (if any).\n`knock-knock` refers to the combination of a genomic location and associated homology donor as a *target*.\nInformation about targets is stored in a directory called `targets` inside a project directory.\n\nGenomic location is specified by providing the name of genome targeted (which must exist in PROJECT_DIR/indices), the protospacer of the (SpCas9) sgRNA that was used for cutting, and the amplicon primers flanking the genomic location of this protospacer that were used to amplify the genomic DNA. \n\nTargets are defined in a set of csv files inside the `targets` directory. A group of "parts-list" files `sgRNAs.csv`, `amplicon_primers.csv`, `donors.csv`, and `extra_sequences.csv` are used to register named sequences of each csv\'s corresponding type, and a master csv file `PROJECT_DIR/targets/targets.csv` defines each target using references to these named sequences.\n\nA target is defined by filling out a row in `PROJECT_DIR/targets/targets.csv`, which must have the following columns:\n\n- `name`: a short, descriptive name for the target\n- `genome`: the name of the genome targeted (which must exist in `PROJECT_DIR/indices`)\n- `sgRNA_sequence`: name of the protospacer sequence that was cut. knock-knock can analyze data produces by cutting with multiple nearby guides in no-donor mode. If there are multiple guides, include all sgRNA names joined by semicolons.\n- `amplicon_primers`: name of the primer pair used to generate the amplicon for sequencing\n- `donor_sequence`: name of the homology-arm-containing donor, if any\n- `nonhomologous_donor_sequence`: name of the non-homology-arm containing donor, if any\n- `extra_sequences`: name(s) of any extra sequences that may be present, joined by semicolons.\n\nAs an example, the contents of the `targets.csv` file included with knock-knock\'s example data are:\n```\nname,genome,sgRNA_sequence,donor_sequence,amplicon_primers,nonhomologous_donor_sequence,extra_sequences\nBCAP31_GFP11_U_ILL,hg38,BCAP31,BCAP31_GFP11_U,BCAP31_ILL,,\nCLTA_GFP11_PCR_ILL,hg38,CLTA,CLTA_GFP11_PCR,CLTA_ILL,,\nRAB11A_150nt_plasmid,hg38,RAB11A,pML217_RAB11A-150HA,RAB11A_PAC,,\nRAB11A_150nt_PCR,hg38,RAB11A,RAB11A-150HA_PCR_donor,RAB11A_PAC,,\n```\n\nFurther details:\n\nThe `sgRNA_sequence` column of `targets.csv` should reference entries in `sgRNAs.csv`.\nEach row of `sgRNAs.csv` defines a single named sgRNA sequence, with columns `name` and `sgRNA_sequence`.\nsgRNA sequences should be given as 5\' to 3\' sequence and not include the PAM.\nThey must exactly match a sequence in the targeted genome.\n\nAs an example, the contents of the `sgRNAs.csv` file included with knock-knock\'s example data are:\n```\nname,sgRNA_sequence\nBCAP31,GATGGTCCCATGGACAAGA\nCLTA,GAACGGATCCAGCTCAGCCA\nRAB11A,GGTAGTCGTACTCGTCGTCG\n```\n\nThe `amplicon_primers` column of `targets.csv` should reference entries in `amplicon_primers.csv`.\nEach row of `amplicon_primers.csv` defines a named amplicon primer pair, with columns `name` and `primer_sequences`.\nPrimer sequences should be given as the 5\' to 3\' sequences of the primer pair (i.e. the two sequences should be on opposite strands) joined by a semicolon.\nIf a primer pair is used together with an sgRNA, there must exist exact matches to the two primer sequences on opposite sides of the sgRNA sequence somewhere in the targeted genome.\n\nAs an example, the contents of the `amplicon_primers.csv` file included with knock-knock\'s example data are:\n\n```\nname,amplicon_primer_sequences\nBCAP31_ILL,GCTGTTGTTAGGAGAGAGGGG;GGGAAGCAGAAGGGCACAAA\nCLTA_ILL,ACCGGATACACGGGTAGGG;AGCCGGGTCTTCTTCGC\nRAB11A_PAC,GCAGTGAAGAAGCTCATTAAGACAAC;GAAGGTAGAGAGAGTTGCCAAATGG\n```\n\nThe `donor_sequence` and `nonhomologous_donor_sequence` columns of `targets.csv` should reference entries in `donors.csv`.\nRows of `donors.csv` define named donors, with columns `name`, `donor_type`, and `donor_sequence`.\nIf a donor is used in the `donor` column of a target definition, its sequence must contain two homology arms that flank the cut site of target\'s sgRNA. \nSetting `donor_type` to `plasmid` causes knock-knock to be aware that the sequence has a circular topology when processing alignments to it.\n\n\nAs an example, the contents of the `donors.csv` file included with knock-knock\'s example data are:\n```\nname,donor_type,donor_sequence\nBCAP31_GFP11_U,ssDNA,CTACTGCTGTGGGATTTCTGTCCCTTTCCAGGCTG...\nCLTA_GFP11_PCR,PCR,GGGAACCTCTTCTGTAACTCCTTAGCGTCGGTTGGTT...\npML217_RAB11A-150HA,plasmid,agcccgaccgctgcgccttatccggtaa...\nRAB11A-150HA_PCR_donor,PCR,GCCGGAAATGGCGCAGCGGCAGGGAGGGG...\n```\n\nwhere the actual donor sequences have been truncated for display purposes.\n\n\nAfter filling out all target-specification csvs, run \n```\nknock-knock build_targets PROJECT_DIR\n```\nto convert the information you have provided into the form needed for subsequent analysis.\n\n### Sample sheets\n\nInput sequencing data fastq files should be stored in a directory called `data` inside the project directory, with each group of experiments (typically from one sequencing run) stored in a further subdirectory (e.g. `PROJECT_DIR/data/EXAMPLE_GROUP`).\n\nEach group subdirectory needs a sample sheet to tell knock-knock which target to align each experiment to.\nSamples are defined by rows in `sample_sheet.csv`.\nEvery sample sheet should contain the columns:\n- `sample`: a short, descriptive name of the sample\n- `platform`: `illumina` or `pacbio`\n- `target_info`: the name of the target (which must have been built as described [above](#specifying-targets))\n- `supplemental_indices`: the name(s) of full genomes to which reads should be aligned, joined by semicolons. This should typically be the name of the targeted organism, plus e_coli if a plasmid donor produced in e. coli was used. Genome names referenced must exist in `PROJECT_DIR/indices` as described [above](#obtaining-reference-sequences-and-building-indices).\n- `color`: an optional color to associate with this sample in visualizations. Can be an integer or any string format that matplotlib recognizes (see [here](https://matplotlib.org/3.1.0/tutorials/colors/colors.html)).\n\nThe columns used to specify which fastq files belong to each sample are different for Illumina and Pacbio sequencing runs.\nIn both cases, all fastq files must be located in `PROJECT_DIR/data/EXAMPLE_GROUP/` and should be given with these leading directory components removed (i.e. as would be returned by `basename`). Fastq files can be gzipped. \n \nIllumina sample sheets should contain columns `R1` and `R2`, which should specify R1 and R2 file names for each sample. \n\nPacbio sample sheets should contain column `CCS_fastq_fn`, which should specify a circular consensus sequence fastq file name for each sample. \n\nAs examples, the contents of `data/illumina/sample_sheet.csv` in knock-knock\'s example data are:\n```\nsample,platform,R1,R2,target_info,supplemental_indices,color\nB_ULT,illumina,BCAP31_ultramer_R1.fastq.gz,BCAP31_ultramer_R2.fastq.gz,BCAP31_GFP11_U_ILL,hg38,1\nC_PCR,illumina,CLTA_PCR_R1.fastq.gz,CLTA_PCR_R2.fastq.gz,CLTA_GFP11_PCR_ILL,hg38,2\n```\n\nand the contents of `data/pacbio/sample_sheet.csv` are:\n```\nsample,platform,CCS_fastq_fn,target_info,supplemental_indices,max_relevant_length,color\nR_plasmid,pacbio,RAB11A_plasmid.fastq.gz,RAB11A_150nt_plasmid,hg38;e_coli,6000,1\nR_PCR,pacbio,RAB11A_PCR.fastq.gz,RAB11A_150nt_PCR,hg38;e_coli,6000,2\n```\n\n### Processing samples\n\nOnce all relevant targets have been built and sample sheets filled out, process sequencing data from a single sample by running \n\n```\nknock-knock process PROJECT_DIR EXAMPLE_GROUP EXAMPLE_SAMPLE\n```\n\nTo process multiple samples in parallel, run\n\n```\nknock-knock parallel PROJECT_DIR MAX_PROCS\n```\n\nwhich will process all samples in all groups in PROJECT_DIR up to MAX_PROCS at a time. To process only samples from a single group,\nrun \n\n```\nknock-knock parallel PROJECT_DIR MAX_PROCS --group EXAMPLE_GROUP\n```\n\n### Generating tables\n\nAfter experiments have been processed, generate tables summarizing the frequencies of different read architectures in each sample by running\n\n```\nknock-knock table BASE_DIR\n```\n\nwhich will create `PROJECT_DIR/results/EXAMPLE_GROUP.html`. See [here](docs/visualization.md#Tables) for an explanation of these tables.\n',
    'author': 'hukai916',
    'author_email': '31452631+hukai916@users.noreply.github.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
